package jeux.entities;

import java.awt.Rectangle;

import jeux.jeu.World;

/**
 * @author jub
 * Les entites de notre jeux
 */
public class Entity {
	/**
	 * Les coordonnes
	 */
	protected int x,y;
	/**
	 * La largeur de l'entit
	 */
	protected int width = 30;
	
	/**
	 * La hauteur de l'entit
	 */
	protected int height = 30;
	/**
	 * Le monde dans lequel se place l'entit
	 */
	protected World world;
	/**
	 * Vraie si l'entit doit tre dtruite, faux sinon. 
	 */
	protected boolean markedForRemoval = false;
	/**
	 * Le nom du sprite li  l'entit;
	 */
	protected String spriteName;
	/**
	 * La vitesse de dplacement de l'entit <br>
	 * (ne doit pas dpcer la moiti de la taille de la plus petite entit, pour qu'une collision puisse tre dtecte)
	 */
	protected int speed=10;
	/**
	 * Un conteur pour limiter les actions
	 */
	protected int t=0;
	
	/**
	 * @param world Le monde avec lequel l'entit va interagir.
	 */
	public Entity(World  world)
	{
		this.world = world;
	}
	
	/**
	 * L'action d'une entit par dfaut aucune action
	 */
	public void act()
	{
		
	}
	/**
	 * @return Le rectangle qui contient l'entit. <br>
	 * Mthode utilise pour la dtection de collisions
	 */
	public Rectangle getBounds(){
		return new Rectangle(x,y,width,height);
	}

	/**
	 * @return La hauteur de l'entit.
	 */
	public int getHeight() {
		return height;
	}

	/**
	 * @return La vitesse de dplacement de l'entit
	 */
	public int getSpeed() {
		return speed;
	}

	/**
	 * @return Le nom du sprite de l'entit
	 */
	public String getSpriteName() {
		return spriteName;
	}

	/**
	 * @return La largeur de l'entit
	 */
	public int getWidth() {
		return width;
	}

	/**
	 * @return L'absice de l'entit
	 */
	public int getX() {
		return x;
	}

	/**
	 * @return L'ordonne de l'entit
	 */
	public int getY() {
		return y;
	}

	/**
	 * @return vrai si l'entit est marque pour tre dtruite.
	 */
	public boolean isMarkedForRemoval() {
		return markedForRemoval;
	}

	/**
	 * @param height dfinie la hauteur
	 */
	public void setHeight(int height) {
		this.height = height;
	}

	/**
	 * @param markedForRemoval Marque l'entit pour tre dtruite
	 */
	public void setMarkedForRemoval(boolean markedForRemoval) {
		this.markedForRemoval = markedForRemoval;
	}

	/**
	 * @param speed dfini la vitesse de dplacement
	 */
	public void setSpeed(int speed) {
		this.speed = speed;
	}

	/**
	 * @param spriteName dfini le sprite de l'entit
	 */
	public void setSpriteName(String spriteName) {
		this.spriteName = spriteName;
	}

	/**
	 * @param width dfini la largeur 
	 */
	public void setWidth(int width) {
		this.width = width;
	}

	/**
	 * @param x dfini l'absice
	 */
	public void setX(int x) {
		this.x = x;
	}

	/**
	 * @param y dfini l'ordonne
	 */
	public void setY(int y) {
		this.y = y;
	}
	
	
}
