package jeux.levels;


import jeux.entities.Entity;
import jeux.entities.Monster;
import jeux.entities.Player;
import jeux.jeu.World;

import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;
import org.newdawn.slick.Input;

import org.newdawn.slick.SlickException;
import org.newdawn.slick.state.BasicGameState;
import org.newdawn.slick.state.StateBasedGame;
import org.newdawn.slick.state.transition.EmptyTransition;
import org.newdawn.slick.state.transition.RotateTransition;

/**
 * @author jub
 * Un niveau est initialis (init), son tat est calcul (update) puis il est raffich (render).
 */
public class Level extends BasicGameState {
	/**
	 * L'identifiant du niveau
	 */
	private int stateID;
	private World world;
	private String music; 
	private Player player;
	/**
	 * Permet de savoir si l'on doit passer au niveau suivant
	 */
	private boolean nextLevelStarting;

	/**
	 * @param stateID l'identifiant du niveau
	 * @param world le monde
	 * @param music la musqiue
	 */
	public Level(int stateID, World world, String music) {
		this.stateID = stateID;
		this.world=world;
		this.music=music;
		this.player=this.world.getPlayer();
		this.nextLevelStarting = false;

	}

	@Override
	public void init(GameContainer container, StateBasedGame game)
			throws SlickException {
		this.world.getMusicCache().getRessource(music).loop();

	}

	@Override
	public void render(GameContainer container, StateBasedGame game, Graphics g)
			throws SlickException {
		if (this.nextLevelStarting)
		{
			String s = "Appuyer sur Enter pour passer au niveau suivant";
			int width = g.getFont().getWidth(s);
			int heigh = g.getFont().getHeight(s);
			g.drawString(s, (world.getWidth()-width)/2, (world.getHeight()-heigh)/2);
		}
		else{
			Entity e;
			Image image;
			for (int i=0; i < this.world.getEntities().size(); i++ )
			{
				e = this.world.getEntities().get(i);
				image=this.world.getSpriteCache().getRessource(e.getSpriteName());
				image. draw(e.getX(), e.getY());
			}
			g.drawString("Level "+this.world.getCurrentLevel(), 0, 0);
		}
		
	}

	@Override
	public void update(GameContainer container, StateBasedGame game, int delta)
			throws SlickException {
		if (this.nextLevelStarting){
			Input input = container.getInput();
			if (input.isKeyDown(Input.KEY_ENTER))
			{
				//prepare le monde pour le niveau suivant;
				this.world.nextLevel();
				this.world.resetCaches();
				for (int i = 0; i< 5*this.world.getCurrentLevel(); i++)
				{
					Monster monster = new Monster(this.world);
					monster.setWidth(30);
					monster.setHeight(30);

					monster.setX((int) (Math.random()*(this.world.getWidth()-monster.getWidth())));
					monster.setY(i*35);
					monster.setSpeed((int) (Math.random()*5+1));

					this.world.addEntity(monster);

				}
				
				game.enterState(this.world.getCurrentLevel(),new RotateTransition(), new EmptyTransition());
				this.nextLevelStarting=false;
			}

		}
		else{
			if (this.world.hasPlayer())
			{
				this.world.actAll(); //Les entites agissent
				Input input = container.getInput(); //permet de rcuperer le gestionnaire d'entres.

				if (input.isKeyDown(Input.KEY_LEFT))
				{
					this.player.moveLeft();
				}
				if (input.isKeyDown(Input.KEY_RIGHT))
				{
					this.player.moveRight();
				}	
				if (input.isKeyDown(Input.KEY_SPACE))
				{
					this.player.fire();
				}
				if (input.isKeyDown(Input.KEY_ESCAPE))
				{
					this.world.removeEntity(this.player);
				}
				this.world.checkCollision(); //Les entites sont marques pour collision 
				this.world.clean();

				if (!this.world.hasMonster())
				{
					if (this.world.hasNextLevel()){
						this.nextLevelStarting=true;

					}
					else
					{
						game.enterState(this.world.getLevelNumber()+1);//passe au menu gagnant
					}
				}
			}
			else
			{
				game.enterState(this.world.getLevelNumber()+2); //passe au menu perdant
			}
		}

	}

	@Override
	public int getID() {
		// TODO Auto-generated method stub
		return this.stateID;
	}



}
